;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "cond-let" "1.1.2"
  "Additional and improved binding conditionals."
  '((emacs "28.1"))
  :url "https://github.com/tarsius/cond-let"
  :commit "21b9e9835756ff5cd1acb971cf9eb56fff671c8b"
  :revdesc "v1.1.2-0-g21b9e9835756"
  :keywords '("extensions")
  :authors '(("Jonas Bernoulli" . "emacs.cond-let@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.cond-let@jonas.bernoulli.dev")))
